//--------------------------------------------------------------
// File     : main.c
// Datum    : 17.08.2014
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Demo der DUAL-FATFS Library
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
//--------------------------------------------------------------

#include "main.h"
#include "stm32_ub_led.h"
#include "stm32_ub_button.h"
#include "stm32_ub_usb_msc_host.h"

//------------------------------------------------------
// Globale Variable
FIL myFile;   // Filehandler

//------------------------------------------------------
void write_to_SD(void) {
  // MMC-Media mounten
  if(UB_Fatfs_Mount(MMC_0)==FATFS_OK) {
	UB_Led_On(LED_ORANGE);
    // File zum schreiben im root neu anlegen
    if(UB_Fatfs_OpenFile(&myFile, "0:/SD_File.txt", F_WR_CLEAR)==FATFS_OK) {
      // ein paar Textzeilen in das File schreiben
      UB_Fatfs_WriteString(&myFile,"SD-Textfile");
      UB_Fatfs_WriteString(&myFile,"hier Zeile zwei");
      UB_Fatfs_WriteString(&myFile,"ENDE");
      // File schliessen
      UB_Fatfs_CloseFile(&myFile);
    }
    // Media unmounten
    UB_Fatfs_UnMount(MMC_0);
    UB_Led_Off(LED_ORANGE);
  }
}

//------------------------------------------------------
void write_to_USB(void) {
  // USB-Media mounten
  if(UB_Fatfs_Mount(USB_1)==FATFS_OK) {
	UB_Led_On(LED_RED);
    // File zum schreiben im root neu anlegen
    if(UB_Fatfs_OpenFile(&myFile, "1:/USB_File.txt", F_WR_CLEAR)==FATFS_OK) {
      // ein paar Textzeilen in das File schreiben
      UB_Fatfs_WriteString(&myFile,"USB-Textfile");
      UB_Fatfs_WriteString(&myFile,"hier Zeile zwei");
      UB_Fatfs_WriteString(&myFile,"ENDE");
      // File schliessen
      UB_Fatfs_CloseFile(&myFile);
    }
    // Media unmounten
    UB_Fatfs_UnMount(USB_1);
    UB_Led_Off(LED_RED);
  }
}

//------------------------------------------------------
int main(void)
{
  uint8_t write_ok=0;

  SystemInit(); // Quarz Einstellungen aktivieren

  // init der LEDs
  UB_Led_Init();
  // init vom Button
  UB_Button_Init();

  // Init vom FATFS-System
  UB_Fatfs_Init();

  // Init vom USB-OTG-Port als MSC-HOST
  // (zum lesen/schreiben auf einen USB-Stick)
  UB_USB_MSC_HOST_Init();

  UB_Led_On(LED_BLUE);


  while(1)
  {
    // pollen vom USB-Status
    if(UB_USB_MSC_HOST_Do()==USB_MSC_DEV_CONNECTED) {
      // wenn USB-Stick erkannt wurde
      UB_Led_On(LED_GREEN);
    }
    else {
      UB_Led_Off(LED_GREEN);
    }

    // pollen vom User-Button
    if(UB_Button_Read(BTN_USER)==BTN_PRESSED) {
      if(write_ok==0) {
    	write_ok=1;
        // testfile auf SD-Karte schreiben
        write_to_SD();
        // testfile auf USB-Stick schreiben
        write_to_USB();
      }
    }
    else {
      write_ok=0;
    }
  }
}

